<?

 /*************************************************************************************
 * Filename: contact.php
 *
 * This file is part of the Login JAS plugin.
 * Copyright 2003-2016 by Matthijs Schuurman
 *
 * The Login JAS plugin is free software under the terms of the
 * GNU General Public License version 3 or any later version.
 *
 * For information about the license please refer to:
 * LICENSE.txt in the root of the plugin or http://jas.junerules.com/plugins/contact/
 *************************************************************************************/


 require_once($_path["include"]."cms.php");
 require_once($_path["include"]."data.php");
 require_once($_path["include"]."history.php");
 require_once($_path["include"]."mutilate.php");

 require_once($_path["format"]."email.php");
 require_once($_path["protocol"]."smtp.php");

 class Plugin_contact extends Base_Plugin
 {
  function output()
  {
   global $_config;

   //redirect to HTTPS
   if($this->config["httpsRedirect"]&&!isset($_SERVER["HTTPS"]))
   {
    //HTTPS requires secure coookie
    $params=session_get_cookie_params();

    if(!$params["secure"])
     session_set_cookie_params($params["lifetime"], $params["path"], $params["domain"], true);

    unset($params);

    $url="https://".$_SERVER["HTTP_HOST"].$_SERVER["REQUEST_URI"];
   }
   else
    $url=false;

   //contact text
   $output="";
   if($this->config["title"])
    $output.="<h1>".$this->config["title"]."</h1>\n";
   if($this->config["text"])
    $output.="<div class=\"text\">".$this->config["text"]."</div><br/>\n";

   //setup feedback module
   $d=Data::cache("contact_feedback", "add", "item");

   $d->field["user"]["valuetype"]="set"; //ensure current user is used (and not root)

   $d->field["catnr"]["properties"].=";hidden";
   if($this->config["feedbackcatnr"])
    $d->setValue("catnr", $this->config["feedbackcatnr"]);

   foreach($d->check("use", "form") as $field)
   {
    if(!$d->check("properties", "default", $field)&&!$d->check("properties", "control", $field))
    {
     if(in_array($field, $this->config["fields"])) //use field
     {
      $d->field[$field]["properties"]=str_replace(";hidden", "", $d->field[$field]["properties"]);

      if(in_array($field, $this->config["required"])) //required field
       $d->field[$field]["min"]=1;
      else //not required
       $d->field[$field]["min"]=0;
     }
     else //don't use field
     {
      $d->field[$field]["properties"].=";hidden";
      $d->field[$field]["min"]=0;
     }
    }
   }

   if(!$d->check("properties", "hidden", "topics"))
   {
    $topics=Array("");
    foreach(explode(",", $this->config["topics"]) as $topic)
     $topics[]=trim($topic);

    $d->listOptions("topic", $topics);
   }

   if($this->config["useCaptcha"])
   {
    $d->addField("captcha", "captcha", "form", "", 0, 5, "", "Captcha");
    $d->field["captcha"]["group"]=2;
    $d->setRequestValue("captcha");
   }

   $d->addField("s", "submit", "form", "", false, false, "Send", "");
   $d->field["s"]["group"]=2;

   //contact feedback form
   $hs=new History();
   $hs->cms();

   $config=Array(
    "handleSubmit" => false,
    "showText" => false,
    "showTitles" => false,
    "showSubmit" => false,
    "showSubmitAdditional" => false,
    "showCancel" => false,
    "reloadPage" => false,
   );

   $cms=new CMS($config);
   $cms->setData($d);
   $cms->referenceManipulation=false;

   foreach($this->plugin->vars as $k => $v)
    $cms->addVar($k, $v);

   if(request("s"))
   {
    $_config->su(true); //root
    $success=$d->submit();
    $_config->su(); //previous user
   }
   else
    $success=false;

   if($success)
   {
    $output.=Mutilate::markupDecodeS($this->config["success"]);

    if($this->config["email"])
     $this->sendEmail($d->getValue("nr"), $this->config["email"]);
   }
   else
    $output.=$cms->form($url)."<br/>";

   return $output;
  }

  function sendEmail($nr, $address)
  {
   global $_config, $_path;

   //get feedback
   $d=Data::cache("contact_feedback", "view", "item");

   $d->clearValues();
   $d->setValue("nr", $nr);

   if(!$d->get()||!$d->next())
   {
    $this->e->add($d->e);
    return false;
   }

   $subject=$this->plugin->l->t("Contact");
   if($d->v["topic"])
    $subject.=": ".$d->v["topic"];
   if($d->v["subject"])
    $subject.=($d->v["topic"]?" - ":": ").$d->v["subject"];

   $replyto="";
   $message="<html><body>\n";
   $message.=$d->v["message"]."<br/>\n<br/>\n";

   if($d->v["email"]||$d->v["name"])
   {
    $message.=$this->plugin->l->t("From").": ";

    if($d->v["name"])
    {
     if($d->v["email"])
      $replyto.=$d->v["name"];

     $message.=$d->v["name"];
    }

    if($d->v["email"])
    {
     $replyto.=($d->v["name"]?" ":"")."<".$d->v["email"].">";
     $message.=($d->v["name"]?" ":"")."&lt;<a href=\"".$d->v["email"]."\" title=\"\">".$d->v["email"]."</a>&gt;";
    }

    $message.="<br/>\n";
   }

   $url=(isset($_SERVER["HTTPS"])?"https":"http")."://".$_SERVER["HTTP_HOST"].$_SERVER["REQUEST_URI"]; //source URL
   $message.=$this->plugin->l->t("Source").": <a href=\"".$url."\" title=\"".$this->plugin->l->t("Source")."\">".$url."</a><br/\n";

   $message.="</body></html>\n";

   //prepare email
   $email=new Format_Email();

   $email->from("contact@".$email->config["defaultDomain"], $this->plugin->l->t("Contact"));
   $email->to($address);

   if($replyto)
    $email->set("Reply-To", $replyto);

   $email->subject($subject);
   $email->message($message, true); //html+text message

   //send email
   $smtp=new Protocol_SMTP();
   if(!$smtp->send($email))
   {
    $this->data->e->add($smtp->e);
    return false;
   }

   return true;
  }
 }
?>
